@@ -37,11 +37,19 @@
 colClass <- function(x)
 UseMethod("colClass")
 
-colClass.default <- function(x){
-  cl <- class(x)
-  cl[length(cl)]
+if(getRversion() < "2.12.0"){
+  colClass.default <- function(x){
+    cl <- class(x)
+    cl[length(cl)]
+  }
+}else{
+  colClass.default <- function(x){
+    cl <- class(x)
+    if(inherits(x, "POSIXct")) "POSIXct" else cl[length(cl)]
+  }
 }
 
+
 colClass.ff <- function(x){
   if (length(x))
     x <- x[1]
@@ -425,11 +433,12 @@ read.table.ffdf <- function(
 
     rt.args$nrows <- first.rows
 
-    if (is.null(transFUN))
-      dat <- do.call(FUN, rt.args)
-    else
-      dat <- transFUN(do.call(FUN, rt.args))
+    dat <- do.call(FUN, rt.args)
+    n.orig <- nrow(dat)
+    if (!is.null(transFUN))
+      dat <- transFUN(dat)
 
+    need.next <- n.orig==first.rows
     n <- nrow(dat)
     N <- n
 
@@ -467,7 +476,7 @@ read.table.ffdf <- function(
     rt.args$header <- FALSE
   }
 
-  if (append || N==first.rows){
+  if (append || need.next){
 
     k <- ncol(x)
     rt.args$col.names <- colnames(x)
@@ -494,18 +503,19 @@ read.table.ffdf <- function(
     while(TRUE){
       if (nrows>=0L && N+next.rows > nrows)
         rt.args$nrows <- nrows - N
-      if (rt.args$nrows<1L)
+      if (rt.args$nrows<1L){
         break
+      }
 
       if (VERBOSE){
         cat("read.table.ffdf ", N+1L,"..", sep="")
         read.start <- proc.time()[3]
       }
 
-      if (is.null(transFUN))
-        dat <- do.call(FUN, rt.args)
-      else
-        dat <- transFUN(do.call(FUN, rt.args))
+      dat <- do.call(FUN, rt.args)
+      n.orig <- nrow(dat)
+      if (!is.null(transFUN))
+        dat <- transFUN(dat)
 
       n <- nrow(dat)
       N <- N + n
@@ -543,8 +553,9 @@ read.table.ffdf <- function(
         cat(" ffdf-write=", round(write.stop-write.start, 3), "sec\n", sep="")
       }
 
-      if (n<rt.args$nrows)
+      if (n.orig<rt.args$nrows){
         break
+      }
 
       rt.args$skip <- 0L
       rt.args$header <- FALSE
